package models

import (
	"github.com/beego/beego/v2/client/orm"
)

type ArticleDetail struct {
	ArticleId            int             `description:"报告id"`
	IsReport             int             `description:"是否属于报告，1是，0否"`
	Title                string          `description:"标题"`
	CategoryName         string          `description:"一级分类"`
	CategoryId           int             `description:"分类ID"`
	CreateDate           string          `description:"创建时间"`
	PublishDate          string          `description:"发布时间"`
	Body                 string          `description:"内容"`
	Abstract             string          `description:"摘要"`
	Annotation           string          `description:"核心观点"`
	IsInterviewApply     bool            `description:"是否申请访谈:true，已申请，false:未申请"`
	InterviewApplyStatus string          `description:"当前访谈申请状态：'待邀请','待访谈','已完成','已取消'"`
	IsFollow             bool            `description:"是否关注，1是，0否"`
	FollowNum            int             `description:"关注数量"`
	IsCollect            bool            `description:"是否收藏:true，已收藏，false:未收藏"`
	CollectionNum        int             `description:"收藏数量"`
	DepartmentId         int             `description:"作者ID"`
	DepartmentImgUrl     string          `description:"作者头像"`
	NickName             string          `description:"作者昵称"`
	HttpUrl              string          `description:"文章链接跳转地址"`
	IsNeedJump           bool            `description:"是否需要跳转链接地址"`
	Seller               SellerResp      `description:"作者昵称"`
	DepartmentDetail     *DepartmentResp `description:"作者昵称"`
}

type SellerResp struct {
	SellerMobile string `description:"销售手机号"`
	SellerName   string `description:"销售名称"`
}

type ArticleDetailResp struct {
	Detail        *ArticleDetail
	HasPermission int `description:"1:有该行业权限,正常展示，2：无该行业权限，不存在权益客户下，3:无该品类权限,已提交过申请，4：无该行业权限,未提交过申请，5：潜在客户，未提交过申请，6：潜在客户,已提交过申请"`
}

func GetArticleDetailById(articleId int) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id = ?  AND publish_status = 1  `
	err = o.Raw(sql, articleId).QueryRow(&item)
	return
}

func GetArticlePermission(companyId int) (item *ChartPermission, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			b.* 
			FROM
			cygx_report_mapping AS a
			INNER JOIN chart_permission AS b ON a.chart_permission_id = b.chart_permission_id 
			WHERE
			a.category_id = ?`
	err = o.Raw(sql, companyId).QueryRow(&item)
	return
}

type ArticleFollowDetail struct {
	DNum   int `description:"作者被关注的数量"`
	MdNum  int `description:"本人是否关注这个作者"`
	AcNum  int `description:"文章被收藏的数量"`
	MacNum int `description:"本人是否收藏这个文章"`
}

//获取文章被关注被收藏的详情
func GetArticleFollowDetail(articleId, uid int) (item *ArticleFollowDetail, err error) {
	//d_num 作者被关注的数量 、 md_num 本人是否关注这个作者 、ac_num 文章被收藏的数量 、 mac_num 本人是否收藏这个文章
	o := orm.NewOrm()
	sql := ` SELECT
	( SELECT count( 1 ) FROM cygx_article_department_follow AS af INNER JOIN wx_user as u ON  u.user_id = af.user_id  WHERE af.department_id = art.department_id AND af.type = 1 ) AS d_num,
	( SELECT count( 1 ) FROM cygx_article_department_follow AS af WHERE af.department_id = art.department_id AND af.type = 1 AND af.user_id = ? ) AS md_num,
	( SELECT count( 1 ) FROM cygx_article_collect AS ac INNER JOIN wx_user as u ON  u.user_id = ac.user_id  WHERE ac.article_id = art.article_id  ) AS ac_num,
	( SELECT count( 1 ) FROM cygx_article_collect AS ac WHERE ac.article_id = art.article_id  AND ac.user_id = ? ) AS mac_num
FROM
	cygx_article AS art
	LEFT JOIN cygx_article_department_follow AS af ON af.department_id = art.department_id
	LEFT JOIN cygx_article_collect AS ac ON ac.article_id = art.article_id 
WHERE
	art.article_id = ?
	GROUP BY art.article_id `
	err = o.Raw(sql, uid, uid, articleId).QueryRow(&item)
	return
}
